# Contributing Guidelines

Thank you for considering contributing to the logEZ project! We appreciate any contributions, including:

- Fixing spelling errors
- Improving documentation
- Adding tests
- Implementing new features
- Fixing bugs
- Providing feedback and suggestions

> Note: We are open to feedback and collaboration. Please feel free to point out any areas where we can improve.

## How can I contribute?

- **Report bugs and suggest features** by using [issues](https://github.com/KunalGehlot/logEZ/issues).
  - When reporting a bug, please include any relevant details or files to help replicate the issue.
  - When suggesting a feature, provide a clear and concise description of the feature and its benefits.

- **Fix issues** by [creating pull requests](https://help.github.com/en/articles/creating-a-pull-request).
  - Before starting work on a pull request, make sure the issue hasn't already been assigned to someone else.
  - When submitting a pull request, provide a clear description of the changes and reference the related issue.

- **Review and discuss** issues and pull requests to help others by sharing your thoughts and insights.

- **Improve documentation** by updating the README, adding docstrings, or creating guides and tutorials.

- **Add tests** to ensure the library's stability and maintainability.

## Before submitting a pull request

Please ensure that you run `nox` before submitting a pull request. This will run the automated tests, linting, and formatting checks for the project, ensuring that your contribution adheres to the project's standards.

To run `nox`, simply execute the following command in your terminal:

```bash
  nox
```

If any issues are found during the `nox` execution, please address them before submitting your pull request.

## Code of Conduct

Please follow our [Code of Conduct](CODE_OF_CONDUCT.md) to foster a welcoming and inclusive environment for all contributors.

## Development Workflow

1. Fork the repository and clone it to your local machine.
2. Set up a virtual environment and install the required dependencies.
3. Make your changes, adhering to the project's coding standards and guidelines.
4. Test your changes and ensure they don't break existing functionality.
5. Commit your changes and push them to your fork.
6. Create a pull request, providing a clear and concise description of your changes.

We look forward to collaborating with you and making logEZ an even more valuable logging library for Python developers!
